[−][src]Trait universal_hash::NewUniversalHash
Instantiate a UniversalHash algorithm.
Associated Types
type KeySize: ArrayLength<u8>
Size of the key for the universal hash function.
Instantiate a UniversalHash algorithm.
type KeySize: ArrayLength<u8>Size of the key for the universal hash function.